# Vardautomation
Package I'm using for my encoding stuff

# How to install vardautomation
This command will install vardautomation and the python dependencies 
```
python -m pip install git+https://github.com/Ichunjo/vardautomation.git -U
```

# Requirements
* Python 3.10 or newer
* VapourSynth r58 & the following plugins `bas`, `ffms2`, `imwri`, `lsmas`, `scxvid`, `wwxd`
* Other modules in `requirements.txt`
